@@ -17,10 +17,14 @@ import uuid
 import warnings
 
 from datetime import datetime
-from functools import wraps
 from pprint import pformat
 from types import FunctionType
 
+if sys.version_info >= (3, 2):
+    import contextlib
+else:
+    import contextlib2 as contextlib
+
 import raven
 from raven.conf import defaults
 from raven.conf.remote import RemoteConfig
@@ -161,7 +165,8 @@ class Client(object):
             context = {'sys.argv': sys.argv[:]}
         self.extra = context
         self.tags = o.get('tags') or {}
-        self.release = o.get('release')
+        self.environment = o.get('environment') or None
+        self.release = o.get('release') or os.environ.get('HEROKU_SLUG_COMMIT')
 
         self.module_cache = ModuleProxyCache()
 
@@ -327,8 +332,8 @@ class Client(object):
                 'stacktrace': stack_info,
             })
 
-        if 'stacktrace' in data and self.include_paths:
-            for frame in data['stacktrace']['frames']:
+        if self.include_paths:
+            for frame in self._iter_frames(data):
                 if frame.get('in_app') is not None:
                     continue
 
@@ -364,6 +369,9 @@ class Client(object):
         if self.release is not None:
             data['release'] = self.release
 
+        if self.environment is not None:
+            data['environment'] = self.environment
+
         data['tags'] = merge_dicts(self.tags, data['tags'], tags)
         data['extra'] = merge_dicts(self.extra, data['extra'], extra)
 
@@ -509,7 +517,7 @@ class Client(object):
                            event (in milliseconds)
         :param extra: a dictionary of additional standard metadata
         :param stack: a stacktrace for the event
-        :param tags: list of extra tags
+        :param tags: dict of extra tags
         :return: a tuple with a 32-length string identifying this event
         """
 
@@ -531,6 +539,14 @@ class Client(object):
         """
         return self.remote.is_active()
 
+    def _iter_frames(self, data):
+        if 'stacktrace' in data:
+            for frame in data['stacktrace']['frames']:
+                yield frame
+        if 'exception' in data:
+            for frame in data['exception']['values'][0]['stacktrace']['frames']:
+                yield frame
+
     def _successful_send(self):
         self.state.set_success()
 
@@ -681,10 +697,11 @@ class Client(object):
         return self.capture(
             'raven.events.Exception', exc_info=exc_info, **kwargs)
 
-    def capture_exceptions(self, function_or_exceptions, **kwargs):
+    def capture_exceptions(self, function_or_exceptions=None, **kwargs):
         """
-        Wrap a function in try/except and automatically call ``.captureException``
-        if it raises an exception, then the exception is reraised.
+        Wrap a function or code block in try/except and automatically call
+        ``.captureException`` if it raises an exception, then the exception
+        is reraised.
 
         By default, it will capture ``Exception``
 
@@ -692,28 +709,41 @@ class Client(object):
         >>> def foo():
         >>>     raise Exception()
 
+        >>> with client.capture_exceptions():
+        >>>    raise Exception()
+
         You can also specify exceptions to be caught specifically
 
         >>> @client.capture_exceptions((IOError, LookupError))
         >>> def bar():
         >>>     ...
 
+        >>> with client.capture_exceptions((IOError, LookupError)):
+        >>>    ...
+
         ``kwargs`` are passed through to ``.captureException``.
         """
-        def make_decorator(exceptions):
-            def decorator(func):
-                @wraps(func)
-                def wrapper(*funcargs, **funckwargs):
-                    try:
-                        return func(*funcargs, **funckwargs)
-                    except exceptions:
-                        self.captureException(**kwargs)
-                        raise
-                return wrapper
-            return decorator
+        function = None
+        exceptions = (Exception,)
         if isinstance(function_or_exceptions, FunctionType):
-            return make_decorator((Exception,))(function_or_exceptions)
-        return make_decorator(function_or_exceptions)
+            function = function_or_exceptions
+        elif function_or_exceptions is not None:
+            exceptions = function_or_exceptions
+
+        # In python3.2 contextmanager acts both as contextmanager and decorator
+        @contextlib.contextmanager
+        def make_decorator(exceptions):
+            try:
+                yield
+            except exceptions:
+                self.captureException(**kwargs)
+                raise
+
+        decorator = make_decorator(exceptions)
+
+        if function:
+            return decorator(function)
+        return decorator
 
     def captureQuery(self, query, params=(), engine=None, **kwargs):
         """
