@@ -56,10 +56,14 @@ class DjangoClient(Client):
             from django.contrib.auth.models import AbstractBaseUser as BaseUser
         except ImportError:
             from django.contrib.auth.models import User as BaseUser  # NOQA
+        except RuntimeError:
+            # If the contenttype / user applications are not installed trying to
+            # import the user models will fail for django >= 1.9.
+            BaseUser = None
 
         result = {}
 
-        if hasattr(request, 'user') and isinstance(request.user, BaseUser):
+        if BaseUser and hasattr(request, 'user') and isinstance(request.user, BaseUser):
             result['user'] = self.get_user_info(request.user)
 
         try:
@@ -74,7 +78,7 @@ class DjangoClient(Client):
             host = get_host(request)
             uri = '%s://%s%s' % (scheme, host, request.path)
 
-        if request.method != 'GET':
+        if request.method not in ('GET', 'HEAD'):
             try:
                 data = request.body
             except Exception:
@@ -108,20 +112,13 @@ class DjangoClient(Client):
     def build_msg(self, *args, **kwargs):
         data = super(DjangoClient, self).build_msg(*args, **kwargs)
 
-        stacks = [
-            data.get('stacktrace'),
-        ]
-        if 'exception' in data:
-            stacks.append(data['exception']['values'][0]['stacktrace'])
+        for frame in self._iter_frames(data):
+            module = frame.get('module')
+            if not module:
+                continue
 
-        for stacktrace in filter(bool, stacks):
-            for frame in stacktrace['frames']:
-                module = frame.get('module')
-                if not module:
-                    continue
-
-                if module.startswith('django.'):
-                    frame['in_app'] = False
+            if module.startswith('django.'):
+                frame['in_app'] = False
 
         if not self.site and 'django.contrib.sites' in settings.INSTALLED_APPS:
             try:
