@@ -45,6 +45,8 @@ class SentryHandler(logging.Handler, object):
         else:
             self.client = client(*args, **kwargs)
 
+        self.tags = kwargs.pop('tags', None)
+
         logging.Handler.__init__(self, level=kwargs.get('level', logging.NOTSET))
 
     def can_record(self, record):
@@ -116,7 +118,7 @@ class SentryHandler(logging.Handler, object):
                 continue
             if k.startswith('_'):
                 continue
-            if '.' not in k and k not in ('culprit', 'server_name'):
+            if '.' not in k and k not in ('culprit', 'server_name', 'fingerprint'):
                 extra[k] = v
             else:
                 data[k] = v
@@ -168,6 +170,8 @@ class SentryHandler(logging.Handler, object):
 
         if hasattr(record, 'tags'):
             kwargs['tags'] = record.tags
+        elif self.tags:
+            kwargs['tags'] = self.tags
 
         kwargs.update(handler_kwargs)
 
